@@ -1,5 +1,7 @@
 aidsEla <- function( coef, W, P = NULL, formula = "AIDS",
-   qNames = NULL, pNames = NULL ) {
+   qNames = NULL, pNames = NULL, coefVcov = NULL, df = NULL ) {
+
+   nGoods <- length( coef$alpha )
 
    if( length( coef$alpha ) != length( coef$beta ) ) {
       stop( "arguments 'alpha' and 'beta' must have the same length" )
@@ -13,6 +15,21 @@ aidsEla <- function( coef, W, P = NULL, formula = "AIDS",
    } else if(  length( coef$alpha ) != length( P ) && !is.null( P ) ) {
       stop( "arguments 'alpha' and 'P' must have the same length" )
    }
+   if( is.null( qNames ) ) {
+      qNames <- .aidsQuantNames( W, coef, nGoods )
+   } else {
+      if( length( qNames ) != nGoods ) {
+         stop( "argument 'qNames' must have ", nGoods, " elements" )
+      }
+   }
+   if( is.null( pNames ) ) {
+      pNames <- .aidsPriceNames( P, coef, nGoods )
+   } else {
+      if( length( pNames ) != nGoods ) {
+         stop( "argument 'pNames' must have ", nGoods, " elements" )
+      }
+   }
+
 
    if( formula %in% c( "AIDS" ) ) {
       if( is.null( P ) ) {
@@ -24,8 +41,6 @@ aidsEla <- function( coef, W, P = NULL, formula = "AIDS",
       }
    }
 
-   nGoods <- length( coef$alpha )
-
    ela <- list()
    ela$formula <- formula
 
@@ -57,7 +72,7 @@ aidsEla <- function( coef, W, P = NULL, formula = "AIDS",
          ( W %*% t( array( 1, c( nGoods ) ) ) )
       ela$hicks <- ela$marshall + ( ela$exp %*% t( array( 1, c( nGoods ) ) ) ) *
          ( array( 1, c( nGoods )) %*% t(W))
-   } else if( formula == "B1 not implemente" ) {
+   } else if( formula == "B1 not implemented" ) {
       ela$exp <- array( 1, c( nGoods ) ) + coef$beta / W
       ela$marshall <- matrix( NA, nGoods, nGoods )
       for( i in 1:nGoods ) {
@@ -75,14 +90,40 @@ aidsEla <- function( coef, W, P = NULL, formula = "AIDS",
    } else {
       stop( "formula '", as.character( formula ), "' is not supported" )
    }
-   if( !is.null( qNames ) ) {
-      rownames( ela$hicks ) <- qNames
-      rownames( ela$marshall ) <- qNames
-      names( ela$exp ) <- qNames
-   }
-   if( !is.null( pNames ) ) {
-      colnames( ela$hicks ) <- pNames
-      colnames( ela$marshall ) <- pNames
+   names( ela$exp )         <- qNames
+   rownames( ela$hicks )    <- qNames
+   colnames( ela$hicks )    <- pNames
+   rownames( ela$marshall ) <- qNames
+   colnames( ela$marshall ) <- pNames
+   if( !is.null( coefVcov ) && formula %in% c( "AIDS" ) ) {
+      jacobian <- aidsElaJacobian( coef = coef, share = W, price = P,
+         formula = formula, qNames = qNames, pNames = pNames )
+      ela$allVcov      <- jacobian$all      %*% coefVcov %*% t( jacobian$all )
+      ela$expVcov      <- jacobian$exp      %*% coefVcov %*% t( jacobian$exp )
+      ela$hicksVcov    <- jacobian$hicks    %*% coefVcov %*% t( jacobian$hicks )
+      ela$marshallVcov <- jacobian$marshall %*% coefVcov %*% t( jacobian$marshall )
+      # standard errors
+      ela$expStEr      <- diag( ela$expVcov )^0.5
+      ela$hicksStEr    <- matrix( diag( ela$hicksVcov )^0.5,
+         ncol = nGoods, byrow = TRUE )
+      ela$marshallStEr <-  matrix( diag( ela$marshallVcov )^0.5,
+         ncol = nGoods, byrow = TRUE )
+      # dim names for standard errors
+      names( ela$expStEr )         <- names( ela$exp )
+      dimnames( ela$hicksStEr )    <- dimnames( ela$hicks )
+      dimnames( ela$marshallStEr ) <- dimnames( ela$marshall )
+      # t-values
+      ela$expTval      <- ela$exp      / ela$expStEr
+      ela$hicksTval    <- ela$hicks    / ela$hicksStEr
+      ela$marshallTval <- ela$marshall / ela$marshallStEr
+      if( !is.null( df ) ) {
+         ela$expPval <- 2 * pt( abs( ela$expTval ), df,
+            lower.tail = FALSE )
+         ela$hicksPval <- 2 * pt( abs( ela$hicksTval ), df,
+            lower.tail = FALSE )
+         ela$marshallPval <- 2 * pt( abs( ela$marshallTval ), df,
+            lower.tail = FALSE )
+      }
    }
    class( ela ) <- "aidsEla"
    return( ela )
