@@ -12,11 +12,11 @@ vcov.maxLik <- function( object, lambdatol=1e-6, ... ) {
       activePar <- rep(TRUE, NParam)
    }
    if(object$code < 100) {
-      if(min(abs(eigen(object$hessian[activePar,activePar],
+      if(min(abs(eigen(object$Hessian[activePar,activePar],
             symmetric=TRUE, only.values=TRUE)$values)) > lambdatol) {
          varcovar <- matrix(0, NParam, NParam)
          varcovar[activePar,activePar] <-
-             solve(-object$hessian[activePar,activePar])
+             solve(-object$Hessian[activePar,activePar])
          return(varcovar)
       }
    }
